{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for LaTeX.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/latex.xml and 'make bootstrap'.
module Skylighting.Syntax.Latex (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for LaTeX.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlatex.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLatex\NUL\NUL\NUL\NUL\NUL\NUL\NULk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBackslashComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBackslashComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\KateResetHL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\KileResetHL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\\\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBackslashMathModeCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBackslashMathModeCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\begin\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathEnvironment\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\end\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvironmentEnd\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\emph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\intertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\mbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\shortintertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textbf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textlf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\textnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\texttt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textup\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathModeText\NUL\\\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BackslashMathModeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BackslashMathModeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\begin\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSFindBeginEnvironmentInMathMode\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\end\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathFindEnd\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\emph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\intertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\mbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\shortintertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textbf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textlf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\textnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\texttt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textup\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathModeText\SOH\\(\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\)\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\[\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\]\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\\\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMBackslashMultilineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMBackslashMultilineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\fi\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\\\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBeginEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBeginEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlstlisting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlstlisting*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListingsEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminted*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintedEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rboxedverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOboxedverbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tverbatim*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbatimEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomment*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommentEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\balignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txalignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxxalignat*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMathEnvWithParam\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIEEEeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rIEEEeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIEEEeqnarraybox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIEEEeqnarraybox*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcases\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcases*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdisplaymath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdisplaymath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\beqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\teqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bequation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tequation*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aflalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bflalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgather\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agather*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmultline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmultline*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsmallmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsmallmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsubeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmatrix*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMathEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlongtable*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmpsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImpsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmpxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmpxtabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabularx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttabularx*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txtabular*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTabEnv\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLatexEnv\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBBeginEnvironmentInMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBBeginEnvironmentInMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlstlisting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlstlisting*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListingsEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminted*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintedEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rboxedverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOboxedverbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tverbatim*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbatimEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomment*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommentEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlongtable*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmpsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImpsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmpxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmpxtabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabularx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttabularx*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txtabular*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTabEnv\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\158(?:equation|IEEEeqnarray(?:box)?|(?:[BVvbp]|small)matrix|(?:fl)?align|x{0,2}alignat|cases|displaymath|gather|math|multline|(?:sub)?eqnarray)(?=[^a-zA-Z]|$)\\*?\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLatexEnv\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\\\end(?=\\s*\\{comment\\*?\\})\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommFindEnd\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEColumn Separator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEColumn Separator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEColumn Separator\NUL}\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomment*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandParameter\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBackslashComment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommentEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommentEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQverb*\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlstinline\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLstinline\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmint\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintParam\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC[a-zA-Z@]+(?:\\+?|\\*{0,3})|.\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\[a-zA-Z]+[^\\{]*\\{\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandParameter\NUL}\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEndEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEndEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLatexEnvEnd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFancyLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFancyLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FancyLabelParameter\NUL[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFancyLabelOption\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFancyLabelRoundBrackets\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFancyLabelOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFancyLabelOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLabelOption\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FancyLabelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FancyLabelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DLE\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\(\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\\\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FancyLabelParameter\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFancyLabelRoundBrackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFancyLabelRoundBrackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\(\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\\\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindBeginEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindBeginEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBeginEnvironment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSFindBeginEnvironmentInMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSFindBeginEnvironmentInMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBBeginEnvironmentInMathMode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f%+\\s*BEGIN\\b\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegionComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n%+\\s*END\\b\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegionComment\NUL%\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindEndEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindEndEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEndEnvironment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFootnoting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFootnoting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFootnotingInside\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFootnotingInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFootnotingInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFootnotingInside\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingC++\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingC++\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^]}]*\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPython\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPython\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^]}]*\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\\\\end\\s*\\{(?:lstlisting|minted)\\*?\\}\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXC++\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginC++\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPython\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^]}]*\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\NUL[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLabelOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLabelOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLabelOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\(\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\\\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLatexEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLatexEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLatexEnvEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLatexEnvEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLatexMacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLatexMacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\begin\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindBeginEnvironment\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\end\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindEndEnvironment\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\Autocite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\Cite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\Citeauthor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\Cref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\Cref*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\Footcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\Parencite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\Textcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\autocite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\autoref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\cite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\citeauthor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\citep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\citet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\citetitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\citeurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\citeyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\cref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\cref*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\eqref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\footcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\footfullcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\fullcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\label\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\nocite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\pagecite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\pageref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\parencite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\subref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\subref*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\supercite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\textcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\vpageref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\vref\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLabel\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\bibliography\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\bibliographystyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\documentclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\includegraphics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\usepackage\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFancyLabel\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\Autocites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\Cites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\Footcites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\Parencites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\autocites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\cites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\footcites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\parencites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\supercites\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFancyLabel\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\chapter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\chapter*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\paragraph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\paragraph*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\part\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\part*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\section\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\section*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\subparagraph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\subparagraph*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\subsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\subsection*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\subsubsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\subsubsection*\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSectioning\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\column\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\definecolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\geometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\hspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\hspace*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\newboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\rule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\setboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\setcounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\setlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\special\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\textcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\vspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\vspace*\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpecialCommand\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\footnote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\footnote*\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFootnoting\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\newcommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\newcommand*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\providecommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\providecommand*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\renewcommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\renewcommand*\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNewCommand\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\edef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\gdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\xdef\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefCommand\SOH\\(\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\SOH\\[\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathModeLatexEquation\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\ensuremath\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeEnsure\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\iffalse\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\\\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListingsEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListingsEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEListingsEnvParam\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEListingsEnvParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEListingsEnvParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNListingsEnvParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ListingsEnvParamEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ListingsEnvParamEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNListingsEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNListingsEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\s*language\\s*=\\s*(?=[^],])\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ListingsEnvParamEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLstinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLstinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFancyLabelOption\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2LstinlineParameter\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLstinlineEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLstinlineEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLstinlineEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n[^%1\\xd7]*\SOH\t\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2LstinlineParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2LstinlineParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[a-zA-Z]+\\*?|.\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMathEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMathEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeEnv\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeEnv\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMathEnvWithParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMathEnvWithParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMathEnvWithParamInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMathEnvWithParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMathEnvWithParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvParamInside\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathEnvironmentInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvironmentEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvironmentEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANMathEnvironmentEndInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANMathEnvironmentEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANMathEnvironmentEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nensuremath\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLatexEnvEnd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r[^}a-zA-Z]+|.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathEnvironmentInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathEnvironmentInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r[^}a-zA-Z]+|.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\balignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txalignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxxalignat*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathFindEndInside\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIEEEeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rIEEEeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIEEEeqnarraybox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIEEEeqnarraybox*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcases\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcases*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdisplaymath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdisplaymath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\beqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\teqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bequation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tequation*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aflalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bflalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgather\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agather*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmultline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmultline*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsmallmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsmallmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsubeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmatrix*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathFindEndInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NoMathFindEndInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathFindEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathFindEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBackslashMathModeCommon\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathModeDisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathModeDisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH$$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL$\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeEnsure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeEnsure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MathModeEnsureInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MathModeEnsureInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MathModeEnsureInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL{\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MathModeEnsureInside\NUL}\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BackslashMathModeEnv\NUL$\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH\\)\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathModeLatexEquation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathModeLatexEquation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH\\]\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathModeDisplay\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathModeText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathModeText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBMathModeTextParameterStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathModeTextInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathModeTextInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBMathModeTextParameterStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBMathModeTextParameterStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBMathModeTextParameterStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathModeTextInside\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH}[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintedEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintedEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMintedEnvParam\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMintedEnvLang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMintedEnvLang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMintedEnvParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMintedEnvParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MintedEnvParamInside\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MintedEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MintedEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMintedEnvLang\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\\\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMBackslashMultilineComment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNewCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNewCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS(?:\\[\\d\\](?:\\[[^\\]]*\\])?)?\\{\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\NUL}\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NoMathFindEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NoMathFindEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoWeb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoWeb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@\\s*$\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLatexMacro\NUL$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a<<.*>>=\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoWeb\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegionComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegionComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSectioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSectioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESectioningInside\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB[a-zA-Z]+(?:\\+?|\\*{0,3})|.\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESectioningInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESectioningInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESectioningInside\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\(\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningMathMode\NUL\\\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningContrSeq\NUL$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningMathMode\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSectioningMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSectioningMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[a-zA-Z]+\\*?|.\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH$$\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\)\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\]\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSectioningMathContrSeq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpecialCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpecialCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSpecialCommandParameterOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSpecialCommandParameterOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSpecialCommandParameterOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\(\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\\\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL$\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSpecialCommandParameterOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL&\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH@{\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEColumn Separator\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\\\end\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTabFindEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTabEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTabEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTab\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTabFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTabFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlongtable*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmpsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImpsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmpxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmpxtabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabularx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttabularx*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txtabular*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\\\\end(?=\\s*\\{(?:lstlisting|minted)\\*?\\})\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNUnknownHighlightingEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNUnknownHighlightingEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNUnknownHighlightingEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerbEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerbEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerbEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n[^%1\\xd7]*\SOH\t\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rboxedverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOboxedverbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tverbatim*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\\\end(?=\\s*\\{verbatim\\*?\\})\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL \\\\end(?=\\s*\\{boxedverbatim\\*?\\})\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\\\end(?=\\s*\\{Verbatim\\*?\\})\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\\\end(?=\\s*\\{BVerbatim\\*?\\})\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\\\end(?=\\s*\\{LVerbatim\\*?\\})\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbatimEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbatimEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tverbatim*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv1\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bverbatim\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv1\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOboxedverbatim*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv2\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rboxedverbatim\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv2\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv3\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVerbatim\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv3\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBVerbatim*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv4\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBVerbatim\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv4\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLVerbatim*\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv5\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLVerbatim\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv5\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim1\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim2\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv3Param\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv3Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv3Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim3\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv4Param\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv4Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv4Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim4\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv5Param\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv5Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv5Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim5\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\185Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)+Holger Danielsson (holger.danielsson@versanet.de)+Michel Ludwig (michel.ludwig@kdemail.net)+Thomas Braun (thomas.braun@virtuell-zuhause.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.tex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ltx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.dtx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.sty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.cls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.bbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.cbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.lbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.tikz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.pgf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
